# Description

This is an example environment for multi-step function calling environment. The dataset can be generated by 
```
python create_examples.py
```


# Licensing information
Code: Apache 2.0
Data: Apache 2.0

Dependencies
- nemo_gym: Apache 2.0
